==> nextcloud-18.0.4.tgz: nextcloud/apps/notifications/l10n/el.js <==
OC.L10N.register(
    "notifications",
    {
    "Admin notifications" : "Ειδοποιήσεις διαχειριστή",
    "Notifications" : "Ειδοποιήσεις",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Εφαρμογή ειδοποιήσεων API για  backend και frontend διαθέσιμο στο Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Εφαρμογή ειδοποιήσεων API για backend και frontend διαθέσιμο στο Nextcloud.\n\t\tΤο API χρησιμοποιήται από άλλες εφαρμογές για παροχή ειδοποιήσεων στον χρήστη σχετικά με διάφορα θέματα. Κάποια παραδείγματα είναι:\n\n📬 Federated κοινόχρηστα: Με τη λήψη νέου κοινόχρηστου\n\n📑 Σχόλια: Όταν κάποιος χρήστης αναφέρει το όνομά σας σε κάποιο αρχείο\n\n🚢  Ειδοποίηση αναβάθμισης: Όταν είναι διαθέσιμη αναβάθμιση εφαρμογής ή του nextcloud\n\n📣  Ανακοινώσεις: Δημοσίευση ανακοίνωσης απο τον διαχειριστή",
    "Dismiss all notifications" : "Εκκαθάριση ειδοποιήσεων",
    "No notifications" : "Καμία ειδοποίηση",
    "Failed to dismiss all notifications" : "Αποτυχία αποδέσμευσης όλων των ειδοποιήσεων",
    "Failed to perform action" : "Αποτυχία εκτέλεσης ενέργειας",
    "Dismiss" : "Αποδέσμευση",
    "Failed to dismiss notification" : "Αποτυχία αποδέσμευσης της ειδοποίησης",
    "in {path}" : "στο {path}"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.14.tgz: nextcloud/apps/notifications/l10n/el.js <==
OC.L10N.register(
    "notifications",
    {
    "Admin notifications" : "Ειδοποιήσεις διαχειριστή",
    "Notifications" : "Ειδοποιήσεις",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Εφαρμογή ειδοποιήσεων API για  backend και frontend διαθέσιμο στο Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Εφαρμογή ειδοποιήσεων API για backend και frontend διαθέσιμο στο Nextcloud.\n\t\tΤο API χρησιμοποιήται από άλλες εφαρμογές για παροχή ειδοποιήσεων στον χρήστη σχετικά με διάφορα θέματα. Κάποια παραδείγματα είναι:\n\n📬 Federated κοινόχρηστα: Με τη λήψη νέου κοινόχρηστου\n\n📑 Σχόλια: Όταν κάποιος χρήστης αναφέρει το όνομά σας σε κάποιο αρχείο\n\n🚢  Ειδοποίηση αναβάθμισης: Όταν είναι διαθέσιμη αναβάθμιση εφαρμογής ή του nextcloud\n\n📣  Ανακοινώσεις: Δημοσίευση ανακοίνωσης απο τον διαχειριστή",
    "Dismiss all notifications" : "Εκκαθάριση ειδοποιήσεων",
    "Requesting browser permissions to show notifications" : "Αίτηση άδειας φυλλομετρητή για εμφάνιση ειδοποιήσεων",
    "No notifications" : "Καμία ειδοποίηση",
    "Failed to dismiss all notifications" : "Αποτυχία αποδέσμευσης όλων των ειδοποιήσεων",
    "Failed to perform action" : "Αποτυχία εκτέλεσης ενέργειας",
    "Dismiss" : "Αποδέσμευση",
    "seconds ago" : " δευτερόλεπτα πριν ",
    "Failed to dismiss notification" : "Αποτυχία αποδέσμευσης της ειδοποίησης",
    "in {path}" : "στο {path}"
},
"nplurals=2; plural=(n != 1);");
